pub enum PinterestLoginError {
CdpError(CdpError),
BrowserConfigBuildError(String),
AuthenticationError,
}Expand description
Pinterest login error type
Variants
CdpError(CdpError)
Chromiumoxide error, returned when chromiumoxide fails to connect to the browser or when the browser fails to load the login page or when the timeout is reached See chromiumoxide::error::CdpError for more details
BrowserConfigBuildError(String)
The browser config builder failed to build the browser config
AuthenticationError
The login bot failed to fill or submit the login form, or the authentication is incorrect